@@ -1,6 +1,5 @@
-from tfkit.model import *
 import tfkit.utility
 import tfkit.dump
 import tfkit.train
 import tfkit.eval
-
+from tfkit.task import *
\ No newline at end of file
