@@ -1,8 +1,9 @@
 import argparse
 import sys
 
-from transformers import AutoModelWithLMHead, AutoModelForSeq2SeqLM
-from tfkit.utility import load_trained_model, add_tokens_to_pretrain
+from transformers import AutoModelWithLMHead, AutoModelForSeq2SeqLM, AutoModelForSequenceClassification
+
+from tfkit.utility.model import load_trained_model, add_tokens_to_pretrain
 
 
 def parse_dump_args(args):
@@ -14,7 +15,7 @@ def parse_dump_args(args):
 
 def main(arg=None):
     arg = parse_dump_args(sys.argv[1:]) if arg is None else parse_dump_args(arg)
-    model, model_type, model_class, model_info = load_trained_model(arg.get('model'))
+    model, model_type, model_class, model_info, model_preprocessor = load_trained_model(arg.get('model'))
     tokenizer = model.tokenizer
     pretrained_config = model_info.get("model_config")
     if model_type == 'clm' and "gpt" in pretrained_config:
@@ -34,6 +35,10 @@ def main(arg=None):
         hf_model.config.tie_encoder_decoder = False
         hf_model, tokenizer = add_tokens_to_pretrain(hf_model, tokenizer, model_info.get('add_tokens', []))
         hf_model.save_pretrained(arg.get('dumpdir'))
+    elif model_type == 'clas':
+        hf_model = AutoModelForSequenceClassification.from_pretrained(model_info.get("model_config"))
+        hf_model.classifier.weight = model.classifier_list[0].weight
+        hf_model.save_pretrained(arg.get('dumpdir'))
     else:
         model.pretrained.save_pretrained(arg.get('dumpdir'))
 
