@@ -32,4 +32,4 @@ class Preprocessor(GeneralNLPPreprocessor):
             else:
                 tokenize_label = [item['task_dict'][task].index(target[0])]
             row_dict['target'] = tokenize_label
-        return {key: torch.tensor(value) for key, value in row_dict.items()}
+        return {key: torch.tensor(value).to(self.device) for key, value in row_dict.items()}
